function idxs = selectAttention( torqueSorted, N, R )
% selectAttention - select attention
%
% Usage:        idxs = selectAttention( torqueSorted, N, R )
%
% input:
%   torqueSorted  - sorted list of torque extrema. each row is a entry of a
%                   extremum, and has to be the following form:
%                   [row,colmn,scale,scale,scaleIdx,torque]
%   N             - number of points to select. if empty, select as many as
%                   possible
%   R             - minimum radius in which selected points has to be
%                   apart. if empty, points are selected so that circles
%                   centered at selected points with their scales do not
%                   overlap. if negative, points are selected without
%                   taking overlapping in consideration.
%
% output:
%   idxs          - indeces to entries of torqueSorted. in other words,
%                   list of selected rows of torqueSorted.
%
% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy
% of this software and associated documentation files (the "Software"), to deal
% in the Software without restriction, subject to the following conditions:
% 
% The above copyright notice and this permission notice shall be included in 
% all copies or substantial portions of the Software.
%
% The Software is provided "as is", without warranty of any kind.

    if exist( 'N', 'var' )~=1 || isempty( N )
        N = size(torqueSorted,1);
    end

    if exist( 'R', 'var' )~=1 || isempty( R )
        R = [];
    end

    % chose tracking points
    flgUsed = false(size(torqueSorted,1),1);
    cnt = 0;
    for i=1:size(torqueSorted,1)                        
        pt  = [torqueSorted(i,2);torqueSorted(i,1)];
        rad = (torqueSorted(i,3)-1)/2;

        flgTooClose = false;
        for j=1:i-1
            if ~flgUsed(j)
                continue;
            end
            pt0  = [torqueSorted(j,2);torqueSorted(j,1)];
            rad0 = (torqueSorted(j,3)-1)/2;
            
            % distance check
            if isempty(R)
                if norm( pt0-pt ) < rad + rad0
                    flgTooClose = true;
                    break;
                end
            else
                if norm( pt0-pt ) < R
                    flgTooClose = true;
                    break;
                end
            end
        end
        
        if flgTooClose
            continue;
        end

        flgUsed(i) = true;

        cnt = cnt + 1;
        if cnt >= N
            break;
        end
    end
    
    idxs = find( flgUsed );
